Multiple signatures are consolidated into a single Attestation in a space-efficient
manner using a BitVec to succinctly express which validators have attested.
Address of a peer, including UDP port number. Convertible to/from SocketAddr. The reason we
don’t just use SocketAddr is that SocketAddr values cannot be directly SCALE
encoded/decoded; PeerAddr values can be.
Identity of a network peer. This is just an Ed25519 public key. The corresponding secret key is
used to sign connection handshakes (the TLS protocol is used).
An extension trait for Nodes which provides various convenience methods. In particular, it
provides wrapper methods which encode/decode data provided to/returned from the underlying
Node methods.
Returns the root of the “constant-depth” Merkle tree containing the given pre-hashed items or
subtree roots plus as many zero-hashes as necessary to bring the number of hashes up to
padded_len. Also returns a “proof” of the item/subtree with the specified index.
Returns the root of the “constant-depth” Merkle tree containing the given pre-hashed items or
subtree roots plus as many zero-hashes as necessary to bring the number of hashes up to
padded_len.
Prepare import proof data for a set of segments.
This function splits the segment into PROVEN_PER_SEGMENT pages and for each page returns
a page prefix proof along with the vector of PROVEN_PER_SEGMENT hashes that form the page.
Returns the root node of the Merkle tree containing the given items plus as many zero-hashes
as necessary to bring the number of items up to padded_len.
Entries relative to epoch N[0]: epoch N entropy accumulator. Updated on each block with fresh entropy.
[i], for 1 ≤ i ≤ 3: accumulator snapshot at the begin of epoch N-i+1.
If N-i+1 < 0 then the corresponding entry is set to some fixed default value.
Identifier of a GRANDPA set of authorities. Although it is similar to EpochIndex it is not
the same. GrandpaSetId starts at 0 at genesis and increments for every set change. This will
normally happen at epoch changes but is not quaranteed to. EpochIndex is a function of time
since JAM common era, hence they might be skipped (eg, after genesis or if the network is down)
but GRANDPA sets are never skipped. They are always incremental from the previous set.