Function block_gas_limit

pub fn block_gas_limit() -> UnsignedGas
The maximum gas which may be used in a single block. At present this is just the product of the maximum gas per work-report and the number of cores. In the future it should probably be more to account for the possibility of always-accumulate services.