pub fn build_encoded_bundle(
package: &WorkPackage,
chunked_extrinsics: impl IntoIterator<Item = impl AsRef<[u8]>>,
imports: &[Vec<ImportData>],
) -> (WorkPackageHash, Vec<u8>)Expand description
Construct an encoded Work Package Bundle from its parts
This function assumes the number of imports and the length of the extrinsics match the Work Package and does not explicitly check that fact.
Returns encoded package hash and the encoded bundle.
Arguments
package: work package.chunked_extrinsics: this iterator goes over arbitrarily chunked extrinsics. All of the chunks are concatenated to form the final extrinsic data.imports: one element for each work package item. Each element contains a vector of import data for that item.