max_block_size

Function max_block_size 

pub fn max_block_size() -> usize
Conservative upper bound on the encoded size of a Block.

Sum of MaxEncodedLen of each bounded Extrinsic field plus a fixed cap on the total preimage data per block (MAX_PREIMAGE_LEN).