pub struct LightExtrinsic {
pub tickets: TicketsXt,
pub preimages: LightPreimagesXt,
pub guarantees: LightGuaranteesXt,
pub assurances: AssurancesXt,
pub disputes: DisputesXt,
}Fields
tickets: TicketsXtpreimages: LightPreimagesXtguarantees: LightGuaranteesXtassurances: AssurancesXtdisputes: DisputesXtTrait Implementations
Sourceimpl Clone for LightExtrinsic
impl Clone for LightExtrinsic
Sourcefn clone(&self) -> LightExtrinsic
fn clone(&self) -> LightExtrinsic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LightExtrinsic
impl Debug for LightExtrinsic
Sourceimpl Decode for LightExtrinsic
impl Decode for LightExtrinsic
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for LightExtrinsic
impl Default for LightExtrinsic
Sourcefn default() -> LightExtrinsic
fn default() -> LightExtrinsic
Returns the “default value” for a type. Read more
Sourceimpl Encode for LightExtrinsic
impl Encode for LightExtrinsic
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for LightExtrinsic