pub struct LightReportGuaranteeEncode<'a> {
pub report_hash: WorkReportHash,
pub slot: Slot,
pub signatures: &'a GuaranteeSignatures,
}Fields
report_hash: WorkReportHashslot: Slotsignatures: &'a GuaranteeSignaturesTrait Implementations
Sourceimpl<'a> Debug for LightReportGuaranteeEncode<'a>
impl<'a> Debug for LightReportGuaranteeEncode<'a>
Sourceimpl<'a> Encode for LightReportGuaranteeEncode<'a>
impl<'a> Encode for LightReportGuaranteeEncode<'a>
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl<'a> EncodeLike for LightReportGuaranteeEncode<'a>