Preimage

Struct Preimage 

pub struct Preimage {
    pub requester: ServiceId,
    /* private fields */
}

Fields

requester: ServiceId

Implementations

Source

impl Preimage

pub fn as_light(&self) -> LightPreimage

Source

impl Preimage

pub fn new_testing(requester: ServiceId, blob: impl Into<Bytes>) -> Self

Utility to create preimage for testing: calculate hash of blob internally. Jam code do not need it as it is either known (persistence) or calculated in decode method.

pub fn new_with_hash( requester: ServiceId, blob: impl Into<Bytes>, hash: Hash, ) -> Self

Warning hash parameter for this method MUST be the hash of the blob (we only add it as parameter to avoid hash computation when already checked, for instance when read from db).

pub fn hash(&self) -> Hash

pub fn blob(&self) -> &Bytes

pub fn encoded_len(blob_len: usize) -> usize