GrandpaSetId

Type Alias GrandpaSetId 

pub type GrandpaSetId = u32;
Identifier of a GRANDPA set of authorities. Although it is similar to EpochIndex it is not the same. GrandpaSetId starts at 0 at genesis and increments for every set change. This will normally happen at epoch changes but is not quaranteed to. EpochIndex is a function of time since JAM common era, hence they might be skipped (eg, after genesis or if the network is down) but GRANDPA sets are never skipped. They are always incremental from the previous set.