pub struct Preimage {
pub requester: ServiceId,
/* private fields */
}Fields
requester: ServiceIdImplementations
Sourceimpl Preimage
impl Preimage
Sourcepub fn new_testing(requester: ServiceId, blob: impl Into<Bytes>) -> Self
pub fn new_testing(requester: ServiceId, blob: impl Into<Bytes>) -> Self
Utility to create preimage for testing: calculate hash of blob internally.
Jam code do not need it as it is either known (persistence) or calculated in decode
method.
Sourcepub fn new_with_hash(
requester: ServiceId,
blob: impl Into<Bytes>,
hash: Hash,
) -> Self
pub fn new_with_hash( requester: ServiceId, blob: impl Into<Bytes>, hash: Hash, ) -> Self
Warning hash parameter for this method MUST be the hash of the blob (we only add it as parameter to avoid hash computation when already checked, for instance when read from db).
pub fn hash(&self) -> Hash
pub fn blob(&self) -> &Bytes
pub fn encoded_len(blob_len: usize) -> usize